@@ -30,7 +30,9 @@ class ModelBase(Parameterized, metaclass=ABCMeta):
     name: Optional[str] = None
     description: Optional[str] = None
 
-    def __init__(self, parameters: Dict[str, Any] = None, output: str = None):
+    def __init__(
+        self, parameters: Optional[Dict[str, Any]] = None, output: Optional[str] = None
+    ):
         """initialize the parameters of the object
 
         Args:
@@ -65,7 +67,7 @@ class ModelBase(Parameterized, metaclass=ABCMeta):
         info = {"time": datetime.now().strftime("%Y-%m-%d %H:%M:%S")}
         return Result(self, result, info=info)
 
-    def write_result(self, output: str = None, result=None) -> None:
+    def write_result(self, output: Optional[str] = None, result=None) -> None:
         """write the result to the output file
 
         Args:
@@ -84,9 +86,13 @@ class ModelBase(Parameterized, metaclass=ABCMeta):
         result.write_to_file(output)
 
     @classmethod
-    def _prepare_argparser(cls, name: str = None) -> argparse.ArgumentParser:
+    def _prepare_argparser(cls, name: Optional[str] = None) -> argparse.ArgumentParser:
         """create argument parser for setting parameters of this model
 
+        Args:
+            name (str):
+                Name of the program, which will be shown in the command line help
+
         Returns:
             :class:`~argparse.ArgumentParser`
         """
@@ -102,7 +108,7 @@ class ModelBase(Parameterized, metaclass=ABCMeta):
         for cls1 in cls.__mro__:
             if hasattr(cls1, "parameters_default"):
                 # add all parameters of this class
-                for p in cls1.parameters_default:  # type: ignore
+                for p in cls1.parameters_default:
                     if p.name not in seen:
                         if not isinstance(p, (HideParameter, DeprecatedParameter)):
                             p._argparser_add(group)
@@ -119,9 +125,16 @@ class ModelBase(Parameterized, metaclass=ABCMeta):
 
     @classmethod
     def from_command_line(
-        cls, args: Sequence[str] = None, name: str = None
-    ) -> "Result":
-        """create model from command line parameters"""
+        cls, args: Optional[Sequence[str]] = None, name: Optional[str] = None
+    ) -> "ModelBase":
+        """create model from command line parameters
+
+        Args:
+            args (list):
+                Sequence of strings corresponding to the command line arguments
+            name (str):
+                Name of the program, which will be shown in the command line help
+        """
         if args is None:
             args = []
 
@@ -145,12 +158,27 @@ class ModelBase(Parameterized, metaclass=ABCMeta):
             parameters.update(json.loads(parameters_json))
 
         # create the model
-        mdl = cls(parameters, output=output)
+        return cls(parameters, output=output)
+
+    @classmethod
+    def run_from_command_line(
+        cls, args: Optional[Sequence[str]] = None, name: Optional[str] = None
+    ) -> "Result":
+        """run model using command line parameters
+
+        Args:
+            args (list):
+                Sequence of strings corresponding to the command line arguments
+            name (str):
+                Name of the program, which will be shown in the command line help
+        """
+        # create model from command line parameters
+        mdl = cls.from_command_line(args, name)
         # run the model
         result = mdl.get_result()
 
         # write the results (if output file was specified)
-        if output:
+        if mdl.output:
             mdl.write_result(output=None, result=result)
 
         return result
@@ -205,14 +233,16 @@ def make_model_class(func: Callable) -> Type[ModelBase]:
     return newclass
 
 
-def make_model(func: Callable, parameters: Dict[str, Any] = None) -> ModelBase:
+def make_model(
+    func: Callable, parameters: Optional[Dict[str, Any]] = None
+) -> ModelBase:
     """create model from a function and a dictionary of parameters"""
     model_class = make_model_class(func)
     return model_class(parameters)
 
 
 def run_function_with_cmd_args(
-    func: Callable, args: Sequence[str] = None, name: str = None
+    func: Callable, args: Optional[Sequence[str]] = None, name: Optional[str] = None
 ):
     """create model from a function and obtain parameters from command line"""
-    return make_model_class(func).from_command_line(args, name=name)
+    return make_model_class(func).run_from_command_line(args, name=name)
